==> artesian-sdk-3.0.0.dev1.tar.gz: artesian-sdk-3.0.0.dev1/Artesian/_ClientsExecutor/Client.py <==
import cgi
import requests
import platform

from .ArtesianJsonSerializer import artesianJsonSerialize, artesianJsonDeserialize
from Artesian._package_info import __version__
from Artesian.Exceptions import (ArtesianSdkException, ArtesianSdkRequestException, ArtesianSdkServerException, ArtesianSdkValidationException, ArtesianSdkForbiddenException, ArtesianSdkOptimisticConcurrencyException)

class _Client:
    def __init__(self, baseUrl, apiKey) -> None:
        sdkVersion = __version__

        artesianAgentString = "'ArtesianSDK-Python:" + sdkVersion + "," + platform.system() + " " + platform.release() + ":"  + platform.version() + ",Python:" + platform.python_version()
        self.__baseUrl = baseUrl
        self.__session = requests.Session()
        self.__session.headers.update({'x-api-key':apiKey, 'Accept':'application/json', 'Accept-Encoding':'gzip', 'X-Artesian-Agent': artesianAgentString})
    def __enter__(self):
        self.__session.__enter__()
        return self
    def __exit__(self, *args):
        self.__session.__exit__(args)
    async def exec(self, method: str, url: str, obj: object = None, retcls: type = None, params:dict = None):        
        json = artesianJsonSerialize(obj)
        url = self.__baseUrl + url
        r = requests.Request(method, url, json=json, params=params)
        prep = self.__session.prepare_request(r)
        try:
            res = self.__session.send(prep)
        except Exception as e:
            raise ArtesianSdkRequestException("Unexpected error while calling {}|{}".format(method,url)) from e

        mimetype, _ = cgi.parse_header(res.headers.get('Content-Type', ''))

        if res.status_code >= 200 and res.status_code < 300:
            if mimetype == 'application/json':
                return artesianJsonDeserialize(res.json(), retcls) if retcls is not None else res.json()
            if mimetype.split('/')[0] == 'text':
                return res.text
            return res.content

        # /upsertData is supposed to returns 204 thus None which would not be distingushable from 404 None
        if res.status_code == 404 and retcls is not None:
            return None
        
        problemDetails = None
        errorText = None

        if mimetype == 'application/problem+json':
            problemDetails = res.json()
        if mimetype == 'application/json' or mimetype.split('/')[0] == 'text':
            errorText = res.text if res.text != "" else None
        
        if res.status_code == 400: # BadRequest
            raise ArtesianSdkValidationException(method, url, res.status_code, problemDetails, errorText)        
        if res.status_code in [409, 412]: # Conflict, PreconditionFailed
            raise ArtesianSdkOptimisticConcurrencyException(method, url, res.status_code, problemDetails, errorText)
        if res.status_code in [401, 403]: # Unauthenticated, Forbidden
            raise ArtesianSdkForbiddenException(method, url, res.status_code, problemDetails, errorText)
        
        # if we reached here it means that is a 500 or another unknown error
        raise ArtesianSdkServerException(method, url, res.status_code, problemDetails, errorText)

==> artesian-sdk-3.0.1.tar.gz: artesian-sdk-3.0.1/Artesian/_ClientsExecutor/Client.py <==
import cgi
from typing import Optional
import requests
import platform

from .ArtesianJsonSerializer import artesianJsonSerialize, artesianJsonDeserialize
from Artesian._package_info import __version__
from Artesian.Exceptions import (ArtesianSdkException, ArtesianSdkRequestException, ArtesianSdkServerException, ArtesianSdkValidationException, ArtesianSdkForbiddenException, ArtesianSdkOptimisticConcurrencyException)

class _Client:
    def __init__(self, baseUrl, apiKey) -> None:
        sdkVersion = __version__

        artesianAgentString = "'ArtesianSDK-Python:" + sdkVersion + "," + platform.system() + " " + platform.release() + ":"  + platform.version() + ",Python:" + platform.python_version()
        self.__baseUrl = baseUrl
        self.__session = requests.Session()
        self.__session.headers.update({'x-api-key':apiKey, 'Accept':'application/json', 'Accept-Encoding':'gzip', 'X-Artesian-Agent': artesianAgentString})
    def __enter__(self):
        self.__session.__enter__()
        return self
    def __exit__(self, *args):
        self.__session.__exit__(args)
    async def exec(self, method: str, url: str, obj: object = None, retcls: Optional[type] = None, params:Optional[dict] = None):        
        json = artesianJsonSerialize(obj)
        url = self.__baseUrl + url
        r = requests.Request(method, url, json=json, params=params)
        prep = self.__session.prepare_request(r)
        try:
            res = self.__session.send(prep)
        except Exception as e:
            raise ArtesianSdkRequestException("Unexpected error while calling {}|{}".format(method,url)) from e

        mimetype, _ = cgi.parse_header(res.headers.get('Content-Type', ''))

        if res.status_code >= 200 and res.status_code < 300:
            if mimetype == 'application/json':
                return artesianJsonDeserialize(res.json(), retcls) if retcls is not None else res.json()
            if mimetype.split('/')[0] == 'text':
                return res.text
            return res.content

        # /upsertData is supposed to returns 204 thus None which would not be distingushable from 404 None
        if res.status_code == 404 and retcls is not None:
            return None
        
        problemDetails = None
        errorText = None

        if mimetype == 'application/problem+json':
            problemDetails = dict(res.json())
        if mimetype == 'application/json' or mimetype.split('/')[0] == 'text':
            errorText = res.text if res.text != "" else None
        
        if res.status_code == 400: # BadRequest
            raise ArtesianSdkValidationException(method, url, res.status_code, problemDetails, errorText)        
        if res.status_code in [409, 412]: # Conflict, PreconditionFailed
            raise ArtesianSdkOptimisticConcurrencyException(method, url, res.status_code, problemDetails, errorText)
        if res.status_code in [401, 403]: # Unauthenticated, Forbidden
            raise ArtesianSdkForbiddenException(method, url, res.status_code, problemDetails, errorText)
        
        # if we reached here it means that is a 500 or another unknown error
        raise ArtesianSdkServerException(method, url, res.status_code, problemDetails, errorText)
